NAME

Perinci::CmdLine::Manual::HowTo::Completion - How-to guides related to completion

VERSION

This document describes version 2.000.2 of Perinci::CmdLine::Manual::HowTo::Completion (from Perl distribution Perinci-CmdLine), released on 2026-03-30.

DESCRIPTION

In a Perinci::CmdLine-based CLI program, shell tab completion is mostly the issue of completing function arguments. A sample Rinci function metadata:

{
  v => 1.1,
  summary => 'A foo utility',
  args => {
    bar => { ... },
    baz => { ... },
  }
}

Function argument names are simple, they are just taken from list of function arguments in the Rinci function metadata:

% myprog --ba<tab>
bar      baz

Completing function argument values is where the meat is. Completion can come from simple sources like schema:

bar => { schema => ['str', in => ['one', 'two', 'three']], ... }

% myprog --bar <tab>
one      three        two

or more complex sources.

Completion from argument schema

TODO

Completion from configuration

TODO

Completion from custom completion routine

TODO

HOMEPAGE

Please visit the project's homepage at https://metacpan.org/release/Perinci-CmdLine.

SOURCE

Source repository is at https://github.com/perlancar/perl-Perinci-CmdLine.

SEE ALSO

Log::ger

AUTHOR

perlancar <perlancar@cpan.org>

CONTRIBUTING

To contribute, you can send patches by email/via RT, or send pull requests on GitHub.

Most of the time, you don't need to build the distribution yourself. You can simply modify the code, then test via:

% prove -l

If you want to build the distribution (e.g. to try to install it locally on your system), you can install Dist::Zilla, Dist::Zilla::PluginBundle::Author::PERLANCAR, Pod::Weaver::PluginBundle::Author::PERLANCAR, and sometimes one or two other Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond that are considered a bug and can be reported to me.

COPYRIGHT AND LICENSE

This software is copyright (c) 2026 by perlancar <perlancar@cpan.org>.

This is free software; you can redistribute it and/or modify it under the same terms as the Perl 5 programming language system itself.

BUGS

Please report any bugs or feature requests on the bugtracker website https://rt.cpan.org/Public/Dist/Display.html?Name=Perinci-CmdLine

When submitting a bug or request, please include a test-file or a patch to an existing test-file that illustrates the bug or desired feature.